@@ -36,24 +36,22 @@ class MILOU_EXPORT DragHelper : public QObject
     Q_PROPERTY(int dragIconSize READ dragIconSize WRITE setDragIconSize NOTIFY dragIconSizeChanged)
 
     public:
-        DragHelper(QObject *parent = 0);
-        ~DragHelper();
+        explicit DragHelper(QObject *parent = nullptr);
+        ~DragHelper() override;
 
         int dragIconSize() const;
         void setDragIconSize(int size);
 
         Q_INVOKABLE bool isDrag(int oldX, int oldY, int newX, int newY) const;
-        // TODO KF6 merge the two
         Q_INVOKABLE void startDrag(QQuickItem* item, QMimeData *mimeData, const QIcon &icon = QIcon());
-        Q_INVOKABLE void startDrag(QQuickItem* item, QMimeData *mimeData, const QString &iconName);
 
     Q_SIGNALS:
-        void dragIconSizeChanged() const;
-        void dropped() const;
+        void dragIconSizeChanged();
+        void dropped();
 
     private:
         int m_dragIconSize;
-        Q_INVOKABLE void doDrag(QQuickItem* item, QMimeData *mimeData, const QIcon &icon = QIcon()) const;
+        Q_INVOKABLE void doDrag(QQuickItem* item, QMimeData *mimeData, const QIcon &icon = QIcon());
 };
 
 }
